pro bbso_name_fix, infil, outdir, outfil=outfil, move=move
;
;+
;NAME:
;	bbso_name_fix
;PURPOSE:
;	Convert the BBSO filename to the Yohkoh convention
;CALLING SEQUENCE:
;	bbso_name_fix, 'hapr01.fts', /move
;INPUT:
;	infil	- The input file(s).  The leading character
;		  must be a "h", "k", "c" or "w". 
;OPTIONAL INPUT:
;	outdir	- The output directory to move the files to.
;		  If not passed, it calls FIND_GBO_DIR to find
;		  the proper GBO weekly directory.
;OPTIONAL KEYWORD INPUT:
;	move	- If set, move the input file to the output
;		  directory with the new file name
;OPTIONAL OUTPUT:
;	outfil	- The new filename for the input file(s)
;HISTORY:
;	Written 29-Jun-92 by M.Morrison
;	27-Jan-93 (MDM) - Modified to use FIND_GBO_DIR to find the 
;			  proper weekly GBO directory.
;	28-Jan-93 (MDM) - Fixed 27-Jan-93 fix
;	19-Aug-94 (MDM) - Patch to handle blank DATE-OBS and TIME-OBS fields
;-
;
qfind = 0
if (n_elements(outdir) eq 0) then qfind = 1
;
outfil = strarr(n_elements(infil))
for i=0,n_elements(infil)-1 do begin
    break_file, infil(i), dsk_log, dir, filnam, ext
   
    img = rfits(infil(i), head=head)

    prefix = 'xxx'
    case strmid(filnam, 0, 1) of	;big bear
		'h': prefix = 'gbh'	;h-alpha
		'k': prefix = 'gbk'	;calcium
		'w': prefix = 'gbw'	;white light
		'c': prefix = 'gbc'	;large scale h-alpha partial frame

		;'i': prefix = 'gbi'
		;'v': prefix = 'gbv'
		;'x': prefix = 'gbx'
		else:
    endcase

    ss = where(strmid(head,0,8) eq 'TIME-OBS')
    tarr = anytim2ex( strmid(head(ss(0)), 11, 8) )
    ss = where(strmid(head,0,8) eq 'DATE-OBS')
    tarr(4) = fix(strmid(head(ss(0)), 11, 2))
    tarr(5) = fix(strmid(head(ss(0)), 14, 2))
    tarr(6) = fix(strmid(head(ss(0)), 17, 2))

    fileid = ex2fid(tarr)
    if (fileid eq '000000.0000') then begin	;MDM added 19-Aug-94
	;filnam = 'haug19a.fts
	tarr = anytim2ex( strmid(filnam, 4, 2) + '-' + strmid(filnam,1,3) )
	fileid = ex2fid(tarr)
    end
    outfil(i) = prefix + fileid
    if (qfind) then outdir = find_gbo_dir(outfil(i), /makedir)

    if (keyword_set(move)) then begin
	cmd = 'mv ' + infil(i) + ' ' + concat_dir(outdir, outfil(i))
	print, cmd
	spawn, cmd
	spawn, 'chmod 666 ' + concat_dir(outdir, outfil(i))
    end
end
;
end
