pro get_selsis, date, interactive=interactive,		$
    halpha=halpha, magnetegram=magnetogram, white=white, optical=optical, $
    calcium=calcium, rename=rename, noninteractive=noninteractive, noftp=noftp, $
    window=windo
;+
;   Name: get_selsis
;
;   Purpose: access selsis solar images , anonymous ftp server.
;
;   History:
;      ~20-Mar-1995 (SLF) - prepare for selsis file server reorganization
;       14-apr-1995 (SLF) - various mods
;	 2-Aug-1995 (MDM) - Added protection for case where the node is
;			    not responding
;
;-

interactive=1-keyword_set(noninteractive)	; changed default
nonint=1-interactive

today=ut_time()
if n_elements(date) eq 0 then date=today
node=get_logenv('SELSIS_FTP_NODE')

; form the name on the selsis ftp server
sdate=str2arr(gt_day(date,/string),'-')
yy=string(sdate(2),format='(i2.2)')
mm=string(month_id(sdate(1)),format='(i2.2)')

subdir=concat_dir(concat_dir('pub','fits'),yy+mm+'_full')

ftp_file=concat_dir(get_logenv('HOME'),'ftp_copy')

message,/info,"Getting directory listing for: " + subdir
inode=node
ftp_copy, inode, /list, subdir=subdir, dirlist=dirlist, ftp_file=ftp_file
if (n_elements(dirlist) eq 0) then begin
    message, /info, "Node not responding -- returning"
    return
end

dircols=str2cols(dirlist)
; file information
files=strtrim(reform(dircols(8,*)),2)
sizes=strtrim(reform(dircols(4,*)),2)
dates= strcompress( reform(dircols(6,*)) + '-' + $
                    reform(dircols(5,*)) + '-' + $
		    (str2arr(gt_day(today,/string),'-'))(2) ,/remove)
times=reform(dircols(7,*))
ydates=fmt_tim(dates + times)		; file creation (not image) times

; identify components of selsis naming convention
sel_fileinfo, files, imgtimes, source, wavelength, ynames=ynames, /convert

if not keyword_set(window) then window=2.	; +/- 2 day window

inttimes=anytim2ints(strtrim(imgtimes,2))

ss=sel_timrange(inttimes, $
   timegrid(date,day=-(window)),timegrid(date,day=window),/between)

if ss(0) eq -1 then begin
   message,/info,"No files within time window..."
   return
endif

files=files(ss)
imgtimes=imgtimes(ss)
source=source(ss)
wavelength=wavelength(ss)
ydates=ydates(ss)
ynames=ynames(ss)

if keyword_set(interactive) then begin
   message,/info,"Select files for transfer..."
   ss=wmenu_sel(files + '   ' + ydates + '  ' + 			   $
                strjustify(source) + ' ' + strjustify(wavelength) + '  ' + $
	        strjustify(strtrim(sizes,2)) + ' bytes')
endif

ftpit=1-keyword_set(noftp)

rename=keyword_set(rename)

outnames=concat_dir(find_gbo_dir(ynames),ynames)
exist= file_exist(outnames)
have = where(exist,hcnt)
need = where(1-exist,ncnt)

case 1 of
   ncnt eq n_elements(outnames): mess="None of the files are online"
   hcnt eq n_elements(outnames): mess="All of the files are already online"
   else: mess="Number of file not online: " + strtrim(ncnt,2)
endcase

flagit='% GET_SELSIS: '
mess=flagit+mess

ftpit = ftpit and (ncnt gt 0)

if ftpit then begin
   if rename then  begin
      mess=[mess,'','% GET_SELSIS: getting files: ','   '+files(need) + ' -> ' + outnames(need)]
      prstr,mess
      ftp_copy, files(need), node, subdir=subdir, /anon, /get, outfil=outnames(need)
   endif else begin
      mess=[mess,'','% GET_SELSIS: getting files:','   '+files(need) + ' -> ' + curdir()]
      prstr,mess
      ftp_copy, files(need), node , subdir=subdir, /anon, /get
   endelse
endif

if nonint then $
   mail,mess,user="freeland@isass0.solar.isas.ac.jp",subj="get_selsis status",/no_def

if n_params() gt 1 then data=rfits2(file,header=header)

file_delete,ftp_file

return
end
