pro kp_name_fix, infil, outdir, outfil=outfil, move=move, copy=copy
;
;+
;NAME:
;	kp_name_fix
;PURPOSE:
;	Convert the Kitt Peak filename to the Yohkoh convention
;CALLING SEQUENCE:
;	kp_name_fix, 'mag920719.fts', /move
;INPUT:
;	infil	- The input file(s).  The leading characters
;		  must be "mag" or "heI"
;OPTIONAL INPUT:
;       outdir  - The output directory to move the files to.
;                 If not passed, it calls FIND_GBO_DIR to find
;                 the proper GBO weekly directory.
;OPTIONAL KEYWORD INPUT:
;	move	- If set, move the input file to the output
;		  directory with the new file name
;OPTIONAL OUTPUT:
;	outfil	- The new filename for the input file(s)
;HISTORY:
;	Written 30-Jul-92 by M.Morrison
;       27-Jan-93 (MDM) - Modified to use FIND_GBO_DIR to find the
;                         proper weekly GBO directory.
;	28-Jan-93 (MDM) - Fixed 27-Jan-93 fix
;-
;
qfind = 0
if (n_elements(outdir) eq 0) then qfind = 1
;
outfil = strarr(n_elements(infil))
for i=0,n_elements(infil)-1 do begin
	break_file, infil(i), dsk_log, dir, filnam, ext
   
	img = rfits(infil(i), head=head)

	prefix = 'xxx'
	case strmid(filnam, 0, 3) of
		'heI': prefix = 'gki'
		'mag': prefix = 'gkm'
		else:
	endcase

	ss = where(strmid(head,0,8) eq 'OBS_TIME')
	if (ss(0) ne -1) then begin
	    time = long(strmid(head(ss(0)), 24, 6))*1000L
	    tarr = anytim2ex( [time, 0] )
	end else begin
	    ss = where(strmid(head,0,7) eq 'UTSTART')
	    tarr = anytim2ex(strmid(head(ss(0)), 11, 8))
	end
	ss = where(strmid(head,0,8) eq 'OBS_DATE')
	if (ss(0) ne -1) then begin
	    tarr(4) = fix(strmid(head(ss(0)), 26, 2))
	    tarr(5) = fix(strmid(head(ss(0)), 24, 2))
	    tarr(6) = fix(strmid(head(ss(0)), 28, 2))
	end else begin
	    ss = where(strmid(head,0,8) eq 'STARTIME')	;seconds past 1-Jan-70
	    a = long(strmid(head(ss(0)), 18, 12))
	    b = long(a/86400.) - 3286			;convert to days past 1-Jan-79
	    tarr0 = anytim2ex([0,b])
	    tarr(4:6) = tarr0(4:6)
	end

	fileid = ex2fid(tarr)
	outfil(i) = prefix + fileid
	if (qfind) then outdir = find_gbo_dir(outfil(i), /makedir)

	if (keyword_set(move)) then begin
	    cmd = 'mv ' + infil(i) + ' ' + concat_dir(outdir, outfil(i))
	    print, cmd
	    spawn, cmd
	    spawn, 'chmod 666 ' + concat_dir(outdir, outfil(i))
	end
	if (keyword_set(copy)) then begin
	    cmd = 'cp -p ' + infil(i) + ' ' + concat_dir(outdir, outfil(i))
	    print, cmd
	    spawn, cmd
	    spawn, 'chmod 666 ' + concat_dir(outdir, outfil(i))
	end
end
;
end

