pro mk_nar, week=week, outdir=outdir, run_time=run_time
;
;+
;NAME:
;	mk_nar
;PURPOSE:
;	Take the daily SELSIS active region summary file and make a 
;	weekly binary log file
;KEYWORD INPUT:
;       week    - a string with the year/week if the format
;                 91_49 where 91 is the year, 49 is the week
;                 This is required input.
;OPTIONAL KEYWORD INPUT:
;	outdir	- The output directory for the output file.
;		  If undefined, write it to $DIR_GEN_NAR.
;HISTORY:
;	Written 4-Jun-92 by M.Morrison
;       28-Aug-92 (MDM) - Modified how RD_FEM was called (call by week#)
;       14-May-93 (MDM) - Changed to use $ydb_raw and $ys
;       24-jan-97 (SLF) - change 'no files' message criteria (rd_selsis changed)
;-
;
start_time = systime(1)
run_time = 0.
;
qdebug = 1
;
progVerNo = 1.00*1000
progName = 'MK_NAR.PRO'
;
if (n_elements(outdir) eq 0) then outdir = '$DIR_GEN_NAR'
;
weekid = string(week, fix(progverno/1000), format="(a, 'a.', i2.2)")
outfil       = concat_dir('$DIR_REFORMAT_SC', 'nar'+weekid)
outfil_final = concat_dir(outdir, 'nar'+weekid)
indir = '$ydb_raw/selsis_regions/'
;
yearn = fix(strmid(week, 0, 2))
weekn = fix(strmid(week, 3, 2))
rd_fem, weekn, yearn, fem_data
ss = where((fem_data.week eq weekn) and (fem_data.day_rev eq 1))
days0 = strlowcase(gt_day(fem_data(ss), /str, /leadzero))
days = str_replace(days0, '-', '')
infil = indir + days + '_region.text'
;
indir2 = '$ydb_raw/selsis_koa/'
doy = anytim2doy( days0 )
infil2 = indir2 + 'ev' + strmid(days0, 7, 2) + '.' + string(doy, format='(i3.3)')
;
rd_selsis, infil, goes, region, infil2=infil2

if not data_chk(region,/struct) then begin
   message,/info,"No regions in all files...
   return
endif   
;
lunout = 2      ;output log
gen_struct, file_header=fhead
;
rsiz = 16
open_da_file, lunout, '', '', outfil, rsiz, bytout, fpoint, /nolower
;
rdwrt, 'W', lunout, bytout, rsiz, region, 1
;
;-------------------- Write out pointer and file header

ndatasets = n_elements(region)
maxsamps = get_nbytes(region(0))
totbytes = bytout

fpoint.TotBytes         = totbytes

;fhead.first_Time        = first_time
;fhead.first_Day         = first_day
;fhead.last_Time         = last_time
;fhead.last_Day          = last_day

fhead.nDataSets         = nDataSets
fhead.maxSamps          = maxSamps

gbo_struct, gbo_version=gbo_version
fpoint.data_version     = gbo_version.nar
file_id = weekid
wrt1p_fh, lunout, fpoint, fhead, rsiz, progName, progVerNo, file_id, 'NAR', 'NAR'
;
close, lunout
;
if (n_elements(outfil_final) ne 0) then begin
    cmd = 'rm -f ' + outfil_final               ;remove any copy of the file that might already exist
    spawn, cmd
    cmd = 'mv ' + outfil + ' ' + outfil_final
    spawn, cmd
end

end_time = systime(1)
run_time = (end_time-start_time)/60.
;
end
