pro mk_soup_hcat, dirs=dirs, files=files, outfil=outfil, headers=headers, qplot=qplot, sort=sort
;
;+
;NAME:
;	mk_soup_hcat
;PURPOSE:
;	To make the catalog of the SOUP headers of files that
;	are currently on-line.
;SAMPLE CALLING SEQUENCE:
;	mk_soup_hcat
;	mk_soup_hcat, dirs='/umbra/data1/soup'
;	mk_soup_hcat, dirs='/umbra/data0/soup', files='*001.rid'
;	mk_soup_hcat, dirs='/umbra/data1/soup', outfil='$ydb/soup/soup_hcat'
;OPTIONAL KEYWORD INPUT:
;	dirs	- The list of directory names to use.  If not
;		  set, it will use:
;			/umbradata0/soup
;			/umbradata1/soup
;	files	- The list of files to look at in the selection.
;		  If not set, it will use:
;			*001.rig*
;		  NOTE: You need to specify 001 in the name because of listing
;		  restrictions.
;	outfil	- The name of the saved output file.  If not
;		  set, it will not save the results to a file.
;	qplot	- If set, call SOUP_OBS and display the results
;	sort	- If set, the time sort the output
;OPTIONAL KEYWORD OUTPUT:
;	headers	- The headers of the SOUP data files which were found
;HISTORY:
;	Written Mar-93 by M.Morrison
;	15-Mar-93 (MDM) - Modified into a procedure
;	16-Apr-93 (MDM) - Modified to look for files *001.rig* instead of
;			  *001.rig and *001.rigd
;			- Added step to save default directory and set 
;			  yourself back there after doing the search
;			- Added /SORT option
;-
;
if (n_elements(dirs) eq 0) then dirs = ['/umbradata0/soup', '/umbradata1/soup']
if (n_elements(files) eq 0) then files = ['*001.rig*']
;;if (n_elements(outfil) eq 0) then outfil = '$ydb/soup/soup_mcat'
;
dirs = concat_dir(dirs, '')		;get the trailing / appended if necessary
;
cd, cur=current_dir
;
ffiles = ''
for idir=0,n_elements(dirs)-1 do begin
    print, 'Looking for base files in directory: ', dirs(idir)
    cd, dirs(idir)
    for ifiles=0,n_elements(files)-1 do begin
	ffiles0 = findfile(files(ifiles))
	if (ffiles0(0) ne '') then ffiles = [ffiles, dirs(idir)+ffiles0]
    end
end
if (n_elements(ffiles) eq 1) then begin
    print, 'No files found in any of the directories'
    return
end
;
base_files = ffiles(1:*)
print, 'Base files found:'
prstr, '    ' + base_files
;
for ibase=0,n_elements(base_files)-1 do begin
    break_file, base_files(ibase), dsk_log, dir, filnam, ext
    cd, dir
    str_sea = strmid(filnam, 0, strlen(filnam)-5) + '*' + ext
    ff = dir + findfile(str_sea)
    print, concat_dir(dir, str_sea), ' has ', n_elements(ff), ' files'
    if (ibase eq 0) then ffiles = ff else ffiles = [ffiles, ff]
end
cd, current_dir
;
print, 'There are a total of: ', n_elements(ffiles), ' files'
print, 'Now reading the headers of these file....'
;
dummy = rd_soup(ffiles, h=headers, /nodata)
;
if (keyword_set(sort)) then begin
    ss = sort(int2secarr(headers))
    headers = headers(ss)
end
;
if (keyword_set(qplot)) then soup_obs, headers
if (keyword_set(outfil)) then savegen, headers, file=outfil
;
end
