pro nob_name_fix, infil, outdir, outfil=outfil, compress=compress
;
;+
;NAME:
;	nob_name_fix
;PURPOSE:
;	Convert the Nobeyama filename to the Yohkoh convention.  Scale
;	the image down to byte type
;CALLING SEQUENCE:
;	nob_name_fix, '/yd8/nobeyama_raw/s930923_14391acp.fits
;INPUT:
;	infil	- The input file(s).  There must be a "acp.fits"
;		  or an "scp.fits"
;OPTIONAL INPUT:
;       outdir  - The output directory to move the files to.
;                 If not passed, it calls FIND_GBO_DIR to find
;                 the proper GBO weekly directory.
;OPTIONAL OUTPUT:
;	outfil	- The new filename for the input file(s)
;HISTORY:
;	Written 4-Oct-93 by M.Morrison
;-
;
if (infil(0) eq '') then return
;
qfind = 0
if (n_elements(outdir) eq 0) then qfind = 1
;
outfil = strarr(n_elements(infil))
for i=0,n_elements(infil)-1 do begin
	print, 'Now Processing: ', infil(i)
	break_file, infil(i), dsk_log, dir, filnam, ext

	img = rfits(infil(i), head=head)
	imin = min(img)   
	imax = max(img)
	bzero = imin
	bscale = (imax-imin)/255.
	img = byte( (img-bzero)/bscale )

	lin1 = 'BZERO   =        ' + string(bzero)  + ' / Yohkoh saves as BYTE scaled'
	lin2 = 'BSCALE  =        ' + string(bscale) + ' / Yohkoh saves as BYTE scaled'
	head2 = head
	ss = where(strmid(head, 0, 8) eq 'BITPIX  ')
	head2(ss) = 'BITPIX  =                    8 / NUMBER OF BITS PER DATA PIXEL
	ss = where(strmid(head, 0, 8) eq 'END     ')
	head2 = [head2(0:ss(0)-1), ' ', lin1, lin2, 'END']

	prefix = 'xxx'
	case strmid(filnam, strlen(filnam)-3, 3) of
		'acp': prefix = 'gnt'
		'scp': prefix = 'gnp'
		else:
	endcase

	ss = where(strmid(head,0,8) eq 'TIME-OBS')
	if (ss(0) ne -1) then begin
            tarr = anytim2ex(strmid(head(ss(0)), 11, 12))
	end else begin
	    stop
	end
	ss = where(strmid(head,0,8) eq 'DATE-OBS')
	if (ss(0) ne -1) then begin
	    tarr2 = anytim2ex(strmid(head(ss(0)), 11, 8))
	end else begin
	    stop
	end
	tarr(4:6) = tarr2(4:6)

	fileid = ex2fid(tarr)
	outfil(i) = prefix + fileid
	if (qfind) then outdir = find_gbo_dir(outfil(i), /makedir)

	print, 'Writing ' + infil(i) + ' out as ' + concat_dir(outdir, outfil(i))
	wrt_fits, concat_dir(outdir, outfil(i)), head2, img
	spawn, 'chmod 666 ' + concat_dir(outdir, outfil(i))

	print, 'Removing ' + infil(i)
	spawn, 'rm -f ' + infil(i)

	if (keyword_set(compress)) then begin
	    print, 'Compressing ' + concat_dir(outdir, outfil(i))
	    spawn, 'compress ' + concat_dir(outdir, outfil(i))
	end
end
;
end
