pro norik_name_fix, infil, outdir, outfil=outfil
;
;+
;NAME:
;	norik_name_fix
;PURPOSE:
;	Convert the Norikura filename to the Yohkoh convention.  Also
;	rotate image to put north up as default on IDL screen.
;CALLING SEQUENCE:
;	norik_name_fix, '/f7p/hara/930927/r1.i0', /move
;INPUT:
;	infil	- The input file(s).  The leading characters
;		  must be "r", "g", or "y"
;OPTIONAL INPUT:
;       outdir  - The output directory to move the files to.
;                 If not passed, it calls FIND_GBO_DIR to find
;                 the proper GBO weekly directory.
;OPTIONAL OUTPUT:
;	outfil	- The new filename for the input file(s)
;HISTORY:
;	Written 1-Oct-93 by M.Morrison
;-
;
qfind = 0
if (n_elements(outdir) eq 0) then qfind = 1
;
outfil = strarr(n_elements(infil))
for i=0,n_elements(infil)-1 do begin
	break_file, infil(i), dsk_log, dir, filnam, ext
   
	img = rfits(infil(i), head=head)
	img = rotate(img, 6)
	head2 = mk_fits_head(img)
	head(0:4) = head2(0:4)

	prefix = 'xxx'
	case strmid(filnam, 0, 1) of
		'r': prefix = 'gnr'
		'g': prefix = 'gng'
		'y': prefix = 'gny'
		else:
	endcase

	ss = where(strmid(head,0,8) eq 'TIME1   ')
	if (ss(0) ne -1) then begin
            tarr = anytim2ex(strmid(head(ss(0)), 11, 8))
	end else begin
	    stop
	end
	ss = where(strmid(head,0,8) eq 'DATE-OBS')
	if (ss(0) ne -1) then begin
	    tarr2 = anytim2ex(strmid(head(ss(0)), 11, 8))
	end else begin
	    stop
	end
	tarr(4:6) = tarr2(4:6)

	fileid = ex2fid(tarr)
	outfil(i) = prefix + fileid
	if (qfind) then outdir = find_gbo_dir(outfil(i), /makedir)

	print, 'Writing ' + infil(i) + ' out as ' + concat_dir(outdir, outfil(i))
	wrt_fits, concat_dir(outdir, outfil(i)), head, img
	spawn, 'chmod 666 ' + concat_dir(outdir, outfil)
end
;
end

