pro pr_nel, st_date, en_date, above=above, qstop=qstop, outfile=outfile, hc=hc
;
;+
;NAME:
;	pr_nel
;PURPOSE:
;	To list the Nobeyama Radio Observatory events
;CALLING SEQUENCE:
;	pr_nel, '1-jan
;	pr_nel, '30-oct-91', '2-nov-91', /hc
;INPUT:
;	st_date	- The UT date to search for.  
;OPTIONAL INPUT:
;	en_date	- The ending date to list data for.  If no date is passed,
;		  it only searches for "st_date"
;OPTIONAL KEYWORD INPUT:
;	outfile	- If a filename is passed, the results will also
;		  be written to that file
;	hc	- If set, write the results to a temporary file, print
;		  it and delete it.
;OUTPUT:
;	The times and classes of the GOES events
;HISTORY:
;	Written 19-Apr-93 by M.Morrison
;-
;
qhc = 0
qout = 0
if (keyword_set(outfile)) then begin
    openw, lunout, outfile, /get_lun
    qout = 1
end
if (keyword_set(hc)) then begin
    openw, lunhc, 'pr_nel.temporary', /get_lun
    qhc = 1
end
;
if (n_elements(st_date) eq 0) then begin
    st_date = strmid(!stime, 0, 6)
end else begin
    ; If the date was provided, make sure to add a yr if none provided:
    day_arr = timstr2ex(st_date)
    if day_arr(6) eq 0 then day_arr(6) = fix(strmid(!stime,9,2))
    st_date = fmt_tim(day_arr)
end
;
day_arr1 = timstr2ex(st_date)
;
if (n_elements(en_date) eq 0) then begin
    ex2int, day_arr1, time, day
    int2ex, time, day+1, day_arr2		;just end 24 hours later
end else begin
    day_arr2 = timstr2ex(en_date)
end
;
if (n_elements(above) eq 0) then above = 0.0
;
rd_nel, fmt_tim(day_arr1), fmt_tim(day_arr2), nel_data, status=status
if (status gt 0) then begin
    print, 'PR_NEL: No events available between ', fmt_tim(day_arr1), ' and ', fmt_tim(day_arr2)
    return
end
;
tit = strarr(5)
tit(0) = 'PR_NEL.PRO Run on: '+ !stime
tit(1) = '  '
tit(2) = '   Start Observing       End Observing     Duration
tit(3) = '       (UT)                                  (hrs)
tit(4) = '  '
        ;'
;
for i=0,n_elements(tit)-1 do begin
    print, tit(i)
    if (qhc) then printf, lunhc, tit(i)
    if (qout) then printf, lunout, tit(i)
end
;
qfirst = 1
for i=0,n_elements(nel_data)-1 do begin
    nel = nel_data(i)

    qwrite = 1
    if (qwrite) then begin
	tim1 = fmt_tim(nel)
	tim2 = fmt_tim( anytim2ints(nel, off=nel.duration))
	dur = nel.duration/60./60.
	str = string(tim1, tim2, dur, format='(2(a,2x), f7.2)')

	print, str 
	if (qhc) then printf, lunhc, str
	if (qout) then printf, lunout, str
    end
end
;
if (qhc) then begin
    free_lun, lunhc
    dprint, 'pr_nel.temporary', /delete
end
if (qout) then free_lun, lunout
;
if (keyword_set(qstop)) then stop
end

