pro rd_gbl_raw, infil, out, filnam=filnam, qdebug=qdebug
;+
;NAME:
;	rd_gbl_raw
;PURPOSE:
;	Read the IDL save file with the GRO/BATSE light curve
;SAMPLE CALLING SEQUENCE:
;	rd_gbl_raw, '/yd3/morrison/batse_raw/gbl910508.1312_f0100_sav', out
;	rd_gbl_raw, '/yd3/morrison/batse_raw/gbl930410.2118_f3881_sav', out
;INPUT:
;	infil	- The IDL save file (it has to be XDR format to be read
;		  on the Unix machine)
;HISTORY:
;	Written 14-Apr-93 by M.Morrison
;	19-Apr-93 (MDM) - Made changes after getting Kim Tolberts message
;			  as to how to interpret ARCHIVE_SEC and ARCHIVE_DATA
;	 7-May-93 (MDM) - Added the -2.042 sec offset for data taken 
;			  before /92/6/25 10:55
;	18-May-93 (MDM) - Changed to use the new IDL (XDR) save files
;-
;
;
if (not file_exist(infil)) then begin
    print, 'MK_GBL: File: ', infil, ' does not exist.  Returning...'
    out = 0b
    return
end
;
gbo_struct, batse_lcur=out_ref
;
restore, file=infil		;an IDL save file
mipseb_dblfixup, flare_datacom	;fix the double precision problem
mipseb_dblfixup, utb		;fix the double precision problem

tim = utb
daytim = anytim2ints([((tim mod 86400))*1000, fix(tim/86400)+1])
;
tarr = anytim2ex(daytim)
file_id = ex2fid(tarr)
filnam = 'gbl' + file_id
;
n = n_elements(archive_sec) / 2
nlow = indgen(n)*2 
nhi  = nlow + 1
archive_sec  = (archive_sec(nlow) and '00ff'x) + 256 * (archive_sec(nhi) and '00ff'x)
archive_data = (archive_data(nlow,*) and '00ff'x) + 256 * (archive_data(nhi,*) and '00ff'x)
;
;scale data from integer*2 variables to true range
sec = xcrange(0) + (xcrange(1)-xcrange(0)) * archive_sec/2e4
data = ycrange(0) + (ycrange(1)-ycrange(0)) * archive_data/2e4
;
tims = anytim2ints(replicate(daytim, n), off=sec)
;
out = replicate(out_ref, n)
out.time = tims.time
out.day  = tims.day
out.channel1 = data(*,0)
out.channel2 = data(*,1)
;
if (keyword_set(qdebug)) then stop
end


