pro rd_hiraiso, infil, fhead, img, bhead, write=write, outdir=outdir
;
;+
;NAME:
;	rd_hirsaiso
;PURPOSE:
;	Read the CRL Hiraiso h-alpha images 
;INPUT:
;	infil	- A single input file name.  The extension must
;		  be .hfd for full disk images and .haf for large
;		  scale images.
;OPTIONAL KEYWORD INPUT:
;	write	- If set, write the image out in FITS format
;	outdir	- If "write" is set, then you can override the
;		  default output directory of $DIR_GBO_CRL using
;		  this keyword.
;OUTPUT:
;	fhead	- The FITS string array image header
;	img	- The image (generally a byte array 640x480)
;OPTIONAL OUTPUT:
;	bhead	- binary header array (bytarr of 512 elements)
;HISTORY:
;	Written 11-Dec-92 by M.Morrison
;	21-Jan-93 (MDM) - Correction to FITS header.  It was always saying
;			  h-alpha, when some input files were calcium.
;			- It was supposed to be all h-alpha
;-
;
bhead = bytarr(512)
img = bytarr(640, 480)		;.hfd files
;
break_file, infil(0), dsk_log, dir, filnam, ext
openr, lun, infil(0), /get_lun
readu, lun, bhead, img
free_lun, lun
;
img = rotate(img, 7)		;flip image top/bottom
;
str = string(bhead(0:26))
date = strmid(str, 0, 8)
time = strmid(str, 10, 2) + ':' + strmid(str, 15, 2) + ':' + strmid(str, 20, 2)
;
fhead = mk_fits_head(img, time=time, date=date)
;
fhead = [fhead, ' ', $
		'ORIGIN  =' + 'HIRAISO C.R.L. JAPAN', $
		'TYPE-OBS=' + 'HALPHA']
;
if (keyword_set(write)) then begin
    if (n_elements(outdir) eq 0) then outdir = '$DIR_GBO_CRL'
    case ext of
	'.hfd': prefix = 'gjh'
	'.haf': prefix = 'gjc'
	else: begin
		print, 'File extension: ', ext, ' is not recognized'
		print, 'Must be either .hfd or .haf'
		return
	      end
    endcase
    ;
    tarr = intarr(7)
    tarr(0) = strmid(time, 0, 2)	;hr
    tarr(1) = strmid(time, 3, 2)	;min
    tarr(2) = strmid(time, 6, 2)	;sec
    tarr(4) = strmid(date, 6, 2)	;date
    tarr(5) = strmid(date, 3, 2)	;month
    tarr(6) = strmid(date, 0, 2)	;year
    fid = ex2fid(tarr)
    outfil = concat_dir(outdir, prefix+fid)
    print, 'File: ', infil, ' Being Saved to: ', outfil
    wrt_fits, outfil, fhead, img
end

end
