pro seltim2yo, date, seltimes, yt0, peak, duration

;   little utiltity time converter..

stimes=strtrim(seltimes,2)
sts=strmid(stimes,0,2) + ':' + strmid(stimes,2,2)
yt0=anytim2ints(fmt_tim(sts(0) + ' ' + date))

pdate=date
edate=date
; peak and end time might span day...
if seltimes(1) lt seltimes(0) then pdate=timegrid(date,/day,/string)
if seltimes(2) lt seltimes(0) then edate=timegrid(date,/day,/string)

peak    =int2secarr(sts(1)+ ' ' + pdate,yt0)     ; in seconds
duration=int2secarr(sts(2)+ ' ' + edate,yt0)

return
end

pro rd_selsis2,infile,events, loud=loud
;
;+
;   Name: rd_selsis2
;
;   Purpose: convert selsis 'event' file to GEV record (new format)
;
;   History:
;     2-Dec-1996 - S.L.Freeland - SEL event file format change
;     3-Dec-1996 - S.L.Freeland - event.location order reversed
;+

gbo_struct, gev_data=event0
event0.location=[-999,-999]                 ; initialize output structures
nfile=n_elements(infile)
allevents=replicate(event0,nfile*30)        ; assume <= 30 Xray events/day

; define some things to extract
things=str2arr('event,startt,peakt,stopt,obs,q,type,location,class,part,region')

xpnt=-1                                ; output structure pointer
ns='' & ew='' & dns=0 & dew=0

loud=keyword_set(loud)
for i=0,nfile-1 do begin               ; for each ascii event file...
   edata=rd_tfile(infile(i))
   estart=where(strpos(edata,'Event') eq 0,ecnt)
   norecs=where(strpos(edata,'NO EVENT REPORTS') eq 0,ncnt)
   case 1 of 
     ncnt ne 0: if loud then message,/info,"No events for: " + infile(i)
     ecnt eq 0: if loud then message,/info,"Cant find event start: " + infile(i)
     else: begin
        date=arr2str((reverse(str2arr(edata(estart(0)-2),' ')))(0:2),'-')
        etable=edata(estart(0)+1:*)
        good=where(strcompress(etable,/remove) ne 0,gcnt)
        etable=etable(good)
        ecols=str2cols(etable,colpos=[0,10,18,28,34,39,42,48,58,64,76])     

        for j=0,n_elements(things)-1 do begin
	   exestring=things(j)+'=strtrim(reform(ecols(j,*)),2)'
	   status=execute(exestring)
        endfor
;       --------- an 'EVENT' is a GOES X-Ray event -------------------

        xr=where(type eq 'XRA',xcnt)           ; xray events
        for j=0,xcnt-1 do begin                ; for each event
          xpnt=xpnt+1                          ; increment record pointer

;         convert event times to GEV equivilent tags
          seltim2yo,date,[startt(xr(j)),peakt(xr(j)),stopt(xr(j))],$
		  xtime,peak,duration

          allevents(xpnt).time=xtime.time      ; fill in some X-ray tags
          allevents(xpnt).day =xtime.day
	  allevents(xpnt).duration=duration
	  allevents(xpnt).peak=peak
	  allevents(xpnt).st$class=byte(strmid(class(xr(j)),0,4))
          if loud then print,'xloop :'+strtrim(j,2) + ' ' + fmt_tim(xtime) + ' ' + string(allevents(xpnt).st$class)
;         ---------- Check for matching OPTICAL/RADIO records ----------
	  match=where(event eq event(xr(j)),ecnt)	  
          fla=where(type(match) eq 'FLA',mcnt)      ; optical matching records
	  if mcnt gt 0 then begin
;            ------ fill in some corresponding OPTICAL tags -----------
	     allevents(xpnt).noaa=fix(region(match(fla(0))))
             loc=strmid(location(match(fla(0))),0,6)
             reads,loc,ns,dns,ew,dew,format='(a1,i2.2,a1,i2.2)'
             allevents(xpnt).location= $
                reverse(([-1,1])(([ns,ew]) eq (['N','W']))*[dns,dew])
             allevents(xpnt).st$halpha=byte(strmid(class(match(fla(0))),0,2))
	   endif
	endfor
      endcase
   endcase
endfor

case 1 of
   xpnt eq -1: events=0
   else:       events=allevents(0:xpnt>0)
endcase

return
end
