pro selsis_copy, idate, recopy=recopy, old_event=old_event
;+
;   Name: selsis_copy
;
;   Purpose: copy (via ftp) daily selsis activity, event  files 
;   	     for specified date (most recent by default)
;
;   Input Parameters:
;      idate - date (UT) to copy
;
;   Keyword Parameters:
;      recopy - if set, force recopy of existing files
;               (default is no recopy)
;
;   History: mdm, 1992
;       18-sep-92 (SLF) - added xray plot and environmental path references
;	14-May-93 (MDM) - Changed to use $ydb_raw and $ys
;       26-May-93 (MDM) - Changed to use /ys/site/script instead of /ys/gen/script
;	19-Aug-93 (MDM) - Removed /SELF switch from mail command
;	30-Aug-93 (MDM) - Had Regions file copy when /XRONLY switch is set (need
;			  to get it earlier)
;       22-Aug-93 (SLF) - use [max91] for regions also (problem with SESC)
;	 3-Jan-94 (MDM) - Modified mailing list
;       10-apr-95 (SLF) - use SELSIS_FTP_NODE environmental - cleanup/file_append
;       12-apr-95 (SLF) - major rewrite to use ftp_copy (for selsis reorganization)
;       28-apr-95 (SLF) - add RECOPY keyword and function
;        5-oct-95 (SLF) - removed X-Ray plot references (now averging 3 sec data)
;        2-dec-96 (SLF) - SEL event file format/name change updates
;-
if keyword_set(idate) then date = gt_day(anytim2ex(anytim2ints(idate)), /str, /leadzero) else $
   date=gt_day(timegrid(ut_time(),day=-1,/string),/str,/leadzero)

if n_elements(idate) eq 0 then idate=date		; return
;
ydbraw=get_logenv('ydb_raw')
outdir1  = concat_dir(ydbraw,'selsis_events')
outdir2  = concat_dir(ydbraw,'selsis_regions')

logdir  = get_logenv('DIR_SITE_SCRIPT')
ftp1=concat_dir(logdir,'selsis_events.ftp')
ftp2=concat_dir(logdir,'selsis_regions.ftp')

yymmmdd=str_replace(date,'-','')

if keyword_set(old_event) then begin
   filnam1=yymmmdd + '_events.text'		; remote name
   eventdir='/pub/indices/VAX_EVENTS'
endif else begin
   filnam1='19'+strmid(ex2fid(anytim2ex(date)),0,6)+'events.txt'
   eventdir='/pub/indices/events'
endelse

mmdd=strmid(ex2fid(anytim2ex(date)),2,4)
filnam2  = mmdd + 'SRS.txt'		        ; remote name
;
ftp_fil = concat_dir(logdir, 'selsis_copy.ftp')

outfil1  = concat_dir(outdir1, strlowcase(filnam1))	; GEV events
outfil2  = concat_dir(outdir2, strlowcase(yymmmdd) + '_region.text'); NAR regions
;
; dont recopy files unless RECOPY is set - slf, 28-apr

if not keyword_set(RECOPY) then begin
   ss1=where(1-file_exist(outfil1),ss1cnt)
   ss2=where(1-file_exist(outfil2),ss2cnt)
endif else begin
   ss1=lindgen(n_elements(outfil1))
   ss2=lindgen(n_elements(outfil2))
   ss1cnt=n_elements(ss1)
   ss2cnt=n_elements(ss2)
endelse

selnode=get_logenv('SELSIS_FTP_NODE')
if selnode eq '' then selnode='ftp.sel.noaa.gov'
if ss1cnt gt 0 then ftp_copy,filnam1(ss1),selnode,eventdir,/anon,/get,outfil=outfil1(ss1),ftp_fil=ftp1
if ss2cnt gt 0 then ftp_copy,filnam2(ss2),selnode,'/pub/forecasts/SRS/',/anon,/get,outfil=outfil2(ss2),ftp_fil=ftp2

end

