pro soon_search, sttim, entim,  catfiles=catfiles, mail=mail, address=address,  $
   outfil=outfil, 								$
   ref_loc=ref_loc, carrington=carrington, helio=helio, ref_date=ref_date,      $
   full_disk=full_disk,	sea_info=sea_info, sea_head=sea_head, 		        $
   gif_file=gif_file, image_list=image_list, ar=ar
;+
;NAME:
;	soon_search
;
;PURPOSE:
;	search the SOON catalog 

;CALLING EXAMPLES:
;       soon_search, starttime, endtime ,/full_disk [,/mail, address='emailadd']
;       soon_search, starttime, endtime ,helio='N12W12',ref_date='9-Jul-94'
;       soon_search, starttime, endtime ,helio='N12W12',ref_date='9-Jul-94', $
;				gif_file="gifname"
;
;HISTORY:
;       23-may-1995 (SLF) - Paramaterized MDM soon_sea (main program)
;       14-jul-1995 (SLF) - add gif_file keyword (passed to plot_gsn)
;       21-jul-1995 (SLF) - add image_list keyword and function
;       24-apr-1996 (SLF) - work around bug in file_seltime
;       26-apr-1996 (SLF) - add AR keyword and function
;        6-Jun-1996 (SLF) - expand AR search (allow SN..., etc)
;-
;
dir = getenv('DIR_GSN_OBS')
prefix = 'st' + ['l','s','h','r']
;


qmail=keyword_set(mail) or keyword_set(address)

if (n_elements(sttim) eq 0) then sttim = ' 1-MAY-94'
if (n_elements(entim) eq 0) then entim = gt_day(!stime, /str)
if (n_elements(catfiles) eq 0) then catfiles = ''
if (n_elements(address) eq 0) then address = get_user() + '@' + get_host()
if (n_elements(sea_info) eq 0) then sea_info = 'NO search location specified'
catfiles=''
for i=0,n_elements(prefix)-1 do $
   catfiles = [catfiles, file_seltime(dir, prefix(i), sttim, entim, /last_before)]

catfiles=catfiles(1:*)
;
en_dis_arr = ['Disabled', 'Enabled']
code = ' '
code2 = ' '
qdone = 0

if not keyword_set(outfil) then $
   outfil = concat_dir(getenv('HOME'), 'soon_sea.temp')

hel=data_chk(helio,/string) and keyword_set(ref_time)
car=keyword_set(carrington)
angle=n_elements(ref_loc) eq 2
arx=keyword_set(ar)
full_disk=keyword_set(full_disk)

case 1 of 
   car: begin
      ref_loc=carrington
      sea_info = 'Search on Carrington Lat/Lon: ' + arr2str(ref_loc)
   endcase
   hel: begin
      if not keyword_set(ref_date) then begin
         tbeep
         message,/info,"Heliographic Coord. Search...."
         message,/info,"You must also supply a reference date via REF_DATE"
         return
      endif
      ref_loc=helio
      sea_info = 'Search on Heliocentric Coordinate: ' + ref_loc + ' for ' + ref_date
   endcase
   arx:sea_info="Search on Active Region# " + string(ar,format='(i4)')
   full_disk: begin
      full_disk=1
      sea_info = 'Search for full disk images'
      ref_loc = 'FULLD'
   endcase
   else: begin
      sea_info = "Search for all Large Scale images"
   endelse
endcase

sea_head = 0b
qfirst = 1
if (catfiles(0) ne '') then for ifil=0,n_elements(catfiles)-1 do begin
   print, 'Searching>>> ' + catfiles(ifil)
   rd_gsn, catfiles(ifil), head		;, obs, imap
   entim_arr = anytim2ints(head, off=head.duration)

   if arx or not keyword_set(ref_loc) then qok=lonarr(n_elements(head))+1 else $
      qok = in_fov(ref_loc, ref_date, gsn=head, carrington = carrington, $
	   helio=helio, full_disk=full_disk, /boolean)
   timok=tim2match(sttim, head, entim_ref=entim, /entim_dur)
   obj = strmid(string(head.st$object),0,4)
   case 1 of 
      arx: begin 
           object=strupcase(strtrim(ar,2))
           object=strtrim(string(object, format= $
              ((['(a6)','(a4)'])(strspecial(object,/digit,/first)))(0)),2)
           tapobj = strmid(string(head.st$object),0,strlen(object))
	   ss = where(timok ge 0 and (tapobj eq object))
      endcase
      full_disk: ss = where(qok and (timok ge 0) and obj eq '9999')
      else: ss=where(qok and timok)
   endcase
   if (ss(0) ne -1) then begin
      if (qfirst) then sea_head = head(ss) else sea_head = [sea_head, head(ss)]
          qfirst = 0
   end
end

sea_tit = ['SOON/SPOT  ' + sea_info, $
' Time range: ' + sttim + ' to ' + entim]

if data_chk(sea_head,/struct) then begin
   pr_gsn, /sum, gsn_head=sea_head, outfil=outfil, comment=sea_tit
   if keyword_set(image_list) then begin
      sum=rd_tfile(outfil)
      pr_gsn, catfiles, summary_arr, /sum, gsn_head=sea_head
      pr_gsn, catfiles, outfil=outfil, comment=sea_tit, tapefile=summary_arr
      file_append,outfil,$
      ['------------------------ SUMMARY LISTING ----------------------------', $
        '',sum,'', 							       $
       '------------------------  IMAGE LISTING  ----------------------------',$
        rd_tfile(outfil)],/new
   endif

   if data_chk(gif_file,/string) then begin
      if gif_file(0) ne '' then $
      plot_gsn, gsn_head=sea_head, tit=arr2str(sea_tit, delim='!c'), $
         gif_file=gif_file
   endif
endif else begin
   file_append,outfil,["******* NO SOONSPOT CATALOG MATCHES FOUND ********"],/new
endelse

if qmail then $
   mail, file=outfil, /no_defsubj, subj="SOON SEARCH RESULTS", user=address

return
end

