pro soup_obs2, header, sel, ss, roadmap=roadmap
;
;+
;NAME:
;	soup_obs2
;PURPOSE:
;	To plot when images are taken for each of the particular
;	wavelength/offset.
;CALLING SEQUENCE:
;	soup_obs2, head
;	soup_obs2, head, sel, ss
;	soup_obs2, head, roadmap=roadmap
;INPUT:
;	header	- The header structure
;OPTIONAL OUTPUT:
;	selimg	- If present, the user is prompted to mark a
;		  starting and ending time of interest.  The value
;                 returned is an array of the same length as
;                 the input array with the selected datasets
;                 having a "1".  The way to use this value is
;                 something like the following:
;                       ss = where(selimg)
;                       ss = where(selimg and (roadmap.percentd eq 255))
;       ss      - Return the list of indicies that were selected.
;                 This should be used only if you do not want to
;                 do other searches using the "where" function.
;HISTORY:
;	Written 16-Apr-93 by M.Morrison (using SOUP_OBS as a start)
;-
;
;;x = int2secarr(header0)
;;ss = sort(x)
;;header = header0(ss)

ref_tim = header(0)
x = int2secarr(header, ref_tim)
xrange0 = [min(x), max(x)]
xrange = xrange0
;
;---
n = n_elements(header)
descr = strarr(n)
for i=0,n-1 do descr(i) = string(header(i).wave, format='(i6)') + string(header(i).offset, format='(i5)') + '/' + header(i).polarity
;^^^ loop needed bcause of "% STRING: Explicitly formated output truncated at limit of 1024 lines." error
u_descr = descr( uniq(descr, sort(descr)) )
y = intarr(n_elements(descr))
for i=0,n_elements(u_descr)-1 do y(where(descr eq u_descr(i))) = i
nn = n_elements(u_descr)
;---
;
if (!d.name eq 'PS') then device, /land
qdone = 0
qhard = 0
qzoom = 1	;always enable it for now

selimg = bytarr(n_elements(x))
while (not qdone) do begin
		erase
		if (keyword_set(roadmap)) then begin	;plot the SXT images first
		    usersym,[0,0],[-1.0,1.0]
		    !p.region = [0, .51, .95, .95]
		    utplot, roadmap, roadmap.seq_num, ref_tim, psym=8, xrange=xrange, ytit='Sequence Number', xmargin=[16,4]
		end
		;
		if (keyword_set(roadmap)) then !p.region = [0, 0, .95,.5] else !p.region = 0
		;
		usersym,[0,0],[-1.5,1.5]
		utplot,header,y,ref_tim, psym=8, $
			ytickname=u_descr,ytickv=indgen(nn),yticks=nn-1,xmargin=[16,4],yrange=[-1,nn], xrange=xrange, /noerase


    qdone = 1
    qavoid = ((!d.name eq 'PS') and (not qhard))        ;user set device to 'PS' outside of routine
    if (qzoom and (not qavoid)) then begin
        if (qhard) then begin
            lprint
            set_plot, save_dev
            qhard = 0
        end
        ss=plot_lcur(header, y, ref_tim, /noplot, extra1='Sel', qblowup=qblowup, qhard=qhard, qreset=qreset, qextra1=qextra1, $
										xsel=xsel, ysel=ysel, /nomultiset)
        qdone = (not qhard and not qblowup and not qreset)
        ;if (qblowup) then xrange=int2secarr(header([ss(0), ss(n_elements(ss)-1)]), ref_tim)
        if (qblowup) then xrange=[min(x(ss)), max(x(ss))]
        if (qreset) then begin
	    xrange = xrange0
	    selimg = bytarr(n_elements(x))	;clear all selections
	end
        if (qhard) then begin
            save_dev = !d.name
            set_plot,'ps
            device, /land
        end
	if (qextra1) then begin
	    n = 1
	    siz = size(xsel)
	    if (siz(0) eq 2) then n = siz(2)
	    for j=0,n-1 do begin
		draw_boxcorn, xsel(0,j), ysel(0,j), xsel(1,j), ysel(1,j), /data
		ss = where( (x ge xsel(0,j)) and (x le xsel(1,j)) and (y ge ysel(0,j)) and (y le ysel(1,j)))
		if (ss(0) ne -1) then selimg(ss) = 1
	    end
	    print, 'There are ', strtrim(fix(total(selimg)),2), ' images selected'
	end
    end
end
;
ss = where(selimg)
if (keyword_set(qstop)) then stop
!p.region = 0
end
